@@ -41,8 +41,13 @@ sub maybe_sleep($self) {
   else { die "something wrong, no events" }
 }
 
+sub stop($self) { $self->is_running(0) }
 
-sub start($self) { local $SIG{PIPE} = 'IGNORE'; $self->maybe_sleep while $self->tick; }
+sub start($self) {
+  $self->is_running(1);
+  local $SIG{PIPE} = 'IGNORE';
+  $self->maybe_sleep while $self->tick && $self->is_running;
+}
 
 1;
 
@@ -58,7 +63,7 @@ Evo::Loop::Comp
 
 =head1 VERSION
 
-version 0.0195
+version 0.0196
 
 =head1 AUTHOR
 
